#
# spec file for package kaffeine
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           kaffeine
Version:        2.0.18git.20230531T022124~afc6c12
Release:        2.1
Summary:        VLC-based Multimedia Player
License:        GPL-2.0-or-later
URL:            https://apps.kde.org/kaffeine/
Source0:        %{name}-%{version}.tar.xz
# PATCH-FEATURE-OPENSUSE kaffeine-fixsplitter.patch -- GUI improvement (allow more flexibly set splitters)
Patch0:         kaffeine-fixsplitter.patch
BuildRequires:  extra-cmake-modules
BuildRequires:  hicolor-icon-theme
BuildRequires:  pkgconfig
BuildRequires:  cmake(KF5CoreAddons)
BuildRequires:  cmake(KF5DBusAddons)
BuildRequires:  cmake(KF5DocTools)
BuildRequires:  cmake(KF5I18n)
BuildRequires:  cmake(KF5KIO)
BuildRequires:  cmake(KF5Solid)
BuildRequires:  cmake(KF5WidgetsAddons)
BuildRequires:  cmake(KF5WindowSystem)
BuildRequires:  cmake(KF5XmlGui)
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5Sql)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5X11Extras)
BuildRequires:  pkgconfig(libdvbv5)
BuildRequires:  pkgconfig(libvlc) >= 3.0
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xscrnsaver)
Requires:       libQt5Sql5-sqlite
Requires:       vlc-noX
Recommends:     vlc-codecs

%description
Kaffeine is a media player.
What makes it different from the others is its excellent support of digital TV (DVB).
Kaffeine has a user-friendly interface so that even first-time users can start immediately
playing their movies: from DVD (including DVD menus, titles, chapters, etc.), VCD, or a file.

%lang_package

%prep
%autosetup -p1

%build
%cmake_kf5 -d build

%cmake_build

%install
%kf5_makeinstall -C build

%find_lang %{name}

%{kf5_find_htmldocs}

%files
%license COPYING
%doc README.md
%doc %lang(en) %{_kf5_htmldir}/en/kaffeine/
%{_kf5_applicationsdir}/org.kde.kaffeine.desktop
%{_kf5_appstreamdir}/org.kde.kaffeine.appdata.xml
%{_kf5_bindir}/kaffeine
%{_kf5_iconsdir}/hicolor/*/*/*
%{_kf5_mandir}/man1/kaffeine.1%{?ext_man}
%{_kf5_sharedir}/kaffeine/
%{_kf5_sharedir}/solid/actions/

%files lang -f %{name}.lang
%{_kf5_mandir}/*/man1/kaffeine.1%{?ext_man}
%{_kf5_htmldir}/*/kaffeine/
%exclude %{_kf5_htmldir}/en/

%changelog
* Wed Nov 20 2024 Christophe Marin <christophe@krop.fr>
- Stop using the %%suse_update_desktop_file macro
* Thu Jun  1 2023 christophe@krop.fr
- Kaffeine is unmaintained upstream but still has users. Switch to
  a git snapshot. Notable changes:
  * Drop kdelirc profile
  * Don't invoke XScreenSaverSuspend on Wayland (kde#460970)
  * Add desktop file name to solid actions
  * Fix activating existing window
  * src/scanfile.dvb: update to latest database
* Mon Nov 23 2020 Christophe Marin <christophe@krop.fr>
- Spec cleanup
* Wed May 15 2019 wbauer@tmo.at
- Update to 2.0.18:
  * Start using TravisCI for test builds
  * mediawidget: Override DVD keys instead of changing their
    settings (kde#394076)
  * mediawidget: warn user to use keys for DVD menu
  * mediawidget: remove a now unneeded check
  * mediawidget: fix video position movement with mouse wheel
  * mediawidget: fix the mouse wheel behavior at the streaming
    window
  * vlc: with vlc 2.x, use vlcMedia for libvlc_MediaMetaChanged
    event (kde#407153)
  * vlc: fix support for vlc 2.x (kde#407153)
- Drop patches merged upstream:
  * fix-support-for-vlc-2.x.patch
  * with-vlc-2.x-use-vlcMedia-for-libvlc_MediaMetaChanged-event.patch
* Sat May  4 2019 wbauer@tmo.at
- Add upstream patches to make it build (and work) with vlc 2.2 on
  Leap 42.3 (kde#407153):
  * fix-support-for-vlc-2.x.patch
  * with-vlc-2.x-use-vlcMedia-for-libvlc_MediaMetaChanged-event.patch
* Thu May  2 2019 wbauer@tmo.at
- Update to 2.0.17:
  * Fix GCC 9 warnings (due to -Wdeprecated-copy)
  * dvbtab: remove unused hide cursor logic
  * dvbdevice: fix a race condition with frontend timeout
  * dvbdevice_linux: improve some warning messages
  * mediawidget: fix a regression with next/previous logic
    (kde#405276)
  * scanfile.dvb: update it to reflect last changes
  * dvbepgdialog: allow showing channels with empty EPG
  * index.docbook: some updates at the doc guide
  * index.docbook: add documentation about XMLTV support
    (kde#405278)
  * Add support for reading EPG from xmltv files (kde#405278)
  * Add support for disabling MPEG-TS EPG reception
  * README.md: add a quick description about xmltv (kde#405278)
  * dvbconfigdialog: remove an extra addLayout()
  * iso-codes: add support for handling 2-letter codes as well
  * dvbdevice_linux: remove unused frontendFd
  * dvb: fix initialization for some objects
  * backend-vlc: don't leak metadata
  * backend-vlc: remove two temporary debug logs
  * backend-vlc: only release libvlc_media_new() when stopped
  * mediawidget: increase language popup size
  * mediawidget: define a policy for the audio combo dropbox
  * backend-vlc: ensure that audio stream will be a valid value
  * backend-vlc: update metadata at stop()
  * backend-vlc: release libvlc_media at destroy method
  * backend-vlc: add other events to the list of possible types
  * backend-vlc: simplify events handling logic
  * backend-vlc: print unhandled libVLC events by name
  * backend-vlc: update audio streams at metadata change
  * mainwindow: associate control bar to main window widget
  * backend-vlc: avoid memory leaks
  * mainwindow: free configuration at exit
  * mainwindow: better implement close event
  * backend-vlc: don't leak timer at object destroy
  * vlcmediawidget: properly initialize the class
  * vlcmediawidget: initialize urlIsAudioCd and trackNumber
    variables
  * backend-vlc: store current audio stream (kde#382546)
- BuildRequire libvlc 3.0 or higher, it fails to build with 2.2.x
  (kde#407153)
* Tue Jan 15 2019 wbauer@tmo.at
- Update to 2.0.16(-2):
  * Update scanfile.dvb to reflect latest channel additions
  * Immediately apply the new audio language if the user changes it
    while a channel is being playing
  * Fix audio language selection issues (kde#402735)
  * Add support for "Original Language" for audio and sub-title
    descriptors
  * Add some new PMT stream_type identifiers in order to allow
    supporting newer audio and video encoding types
  * Add support for High DPI pixel maps (kde#400422)
  * Add a command line option to force an specific aspect ratio
    (kde#394201)
  * Only read/write longitude/latitude from config files for USALS
    satellite configurations (kde#400268)
  * Add support for parallel instant records
  * Fix several issues related to audio CD playing
  * Update build instructions for Debian/Ubuntu and Fedora at
    README.md
  * Fix handling of command line arguments and describe the ones
    that are mutually exclusive at the docs (kde#394000)
  * Fix compilation issues and clean warnings when built with Clang
  * Fix compilation issues with qt5.11-rc2 and with FreeBSD
    (kde#393222)
  * Some code cleanups and typo fixes
- Add full Source URL
- Drop patches merged upstream:
  * 0001-only-use-qPrintable-for-debug-messages.patch
  * 0002-Fix-breakages-with-qt5.11-rc2.patch
  * fix-audio-CD-playing.patch
  * Set-vlcMedia-to-NULL-after-release.patch
* Mon Oct 29 2018 wbauer@tmo.at
- Add fix-audio-CD-playing.patch to make Audio CD playback work
- Add Set-vlcMedia-to-NULL-after-release.patch to prevent a crash
  when the Audio CD cannot be opened for some reason
* Sun Jun  3 2018 christophe@krop.fr
- Add upstream patches:
  - 0001-only-use-qPrintable-for-debug-messages.patch
  - 0002-Fix-breakages-with-qt5.11-rc2.patch
- Run spec-cleaner
* Wed May  2 2018 wbauer@tmo.at
- Update to 2.0.15:
  * Fix logic that handles ATSC EIT entries (regression fix)
    (kde#388962)
  * Auto-hide all bars when in minimal/full screen mode and mouse
    is out of window
  * Allow better control of deinterlacing mode (kde#389783)
  * Better handle higherVoltage settings, as it exists only for
    satellite TV delivery systems (kde#388367)
  * Improve error handling when parsing config.dvb file
    (kde#388367)
  * Change volume wheel logic to accept both point and angle-based
    volume control, accepting it only when the mouse is under the
    media widget
  * Simplify the mouse hide logic
  * Fix DVD menu navigation by using the keyboard instead of the
    mouse (as mouse control is incompatible with newer versions of
    Qt/libVLC) (kde#373814)
  * Fix handling of display mode, correcting some erratic behavior
    (kde#393533)
  * Add options to start Kaffeine on minimal mode and/or with its
    main window always on top
  * When a new record starts and there aren't enough resources to
    keep playing the current DVB channel, switch to the new channel
    instead of stop playing (kde#393647)
  * Improve documentation to match the recent changes
- Drop fix-pt_BR-docs.patch, merged upstream
* Fri Dec  8 2017 wbauer@tmo.at
- Update to 2.0.14:
  * Add support for multi-language EPG
  * Jump to a position was not working, as it was lacking the Ok
    button
  * On minimal and full screen mode, auto-unhide top menu bar and
    lateral DVB tab bar
  * The mouse wheel can now be used to control volume
  * Reduce button size at DVB tab, in order to allow showing a
    bigger playback window
  * Fix LNBf numbering and position at DiSEqC satellite
    configuration
  * Kaffeine's handbook now covers all menu bar items
  * Kaffeine's handbook was improved to contain more details about
    Digital TV settings
  * LNBf names at DVB satellite configuration are now using
    translations from libdvbv5
  * Get rid on two compilation warnings with gcc++ version 7.2
  * scanfile.dvb updated
- Add fix-pt_BR-docs.patch to fix build with kdoctools < 5.41
* Fri Sep 15 2017 wbauer@tmo.at
- Update to 2.0.13:
  * Add a logic to send LNBf higher voltage commands. That may be
    needed on a few devices, if the antenna cabling is too long,
    as, otherwise, polarity setting may not work (kde#374693).
  * Fix layer selection for ISDB-T
  * Improve README.md instructions
  * get rid of incomplete work (dtvdaemon)
  * fix install dir on some distros
  * Shut up a gcc 7.1 warning
  * scanfile.dvb updated.
* Wed Jul 26 2017 wbauer@tmo.at
- Update to 2.0.12.1:
  * Add back man pages that were missing by mistake in 2.0.12
* Wed Jul 19 2017 wbauer@tmo.at
- Update to 2.0.12:
  * Update Changelog to reflect all changes since version 1.3.1
- Update to 2.0.11:
  * Solve performance issues causing kaffeine to use 100%% CPU even
    when video is paused or stopped
  * Fix DVB play on videos that use a separate PID for synchronism
  * Fix some bugs at DVB pause logic, making it more reliable and
    making unpause to continue from the paused position
  * Disable debug messages by default
  * Remove a warning on some DVB streams when a program is not rated
  * Improve notes about video output settings at README.md
- Package README.md too, it contains some hints about known video
  output issues
* Fri Jun 30 2017 wbauer@tmo.at
- Update to 2.0.10:
  * Fix video resize and scale factor issues;
  * Handle parameters when there's a running instance and a new
    kaffeine is called with some URL.
  * Updated scanfile.dvb.
- Drop remove-stray-call-to-ki18n_install.patch, no longer
  necessary
* Sun Jun  4 2017 wbauer@tmo.at
- Update to 2.0.9:
  * Fix build at tarball
- Drop fix-building-from-tarball.patch, included upstream
- Add remove-stray-call-to-ki18n_install.patch to fix build with
  the latest KDE Frameworks in Factory
- Enable DVB support on Leap 42.3 too, v4l-utils are recent enough
* Tue Mar  7 2017 wbauer@tmo.at
- Update to 2.0.8:
  * Added Norwegian Nynorsk translation to .desktop files.
- Update to 2.0.7:
  * Add support for H-265 video streams.
  * Organize debug logs per category, using QLoggingCategory.
- Add fix-building-from-tarball.patch to fix building it from the
  released 2.0.8 tarball.
* Wed Feb 22 2017 wbauer@tmo.at
- Update to 2.0.6:
  * No changelog available
* Wed Dec 14 2016 wbauer@tmo.at
- Require vlc-noX, without it installed kaffeine won't even start
- Recommend vlc-codecs to be able to play more files if the user
  has an appropriate repo added
* Thu Dec  1 2016 jengelh@inai.de
- Description updates
* Wed Nov 30 2016 wbauer@tmo.at
- Update to 2.0.5:
  * No changelog available
* Wed Aug 10 2016 joerg.lorenzen@ki.tng.de
- Update to 2.0.4:
  - No recent changelog available in tarball.
  - Build against kf5 and qt5.
  - Removed patches build-fix.diff, crash-on-resume-fix.patch,
    initial-preference.diff, kaffeine-cmake34.patch,
    kaffeine-gcc47.patch, kaffeine-gcc6.patch, ksuseinstall.diff,
    support_for_sundtek_tv_tuners.patch and
    support_mimetypes_bnc671581.diff, fixed upstream.
  - Fixed patch kaffeine-fixsplitter.patch.
  - Removed source kaffeine-icons.tar.bz2, no longer required.
  - Changed summary and description because kaffeine now builds
    against libvlc, libxine is no longer needed for build.
* Fri Jun 17 2016 wbauer@tmo.at
- Add kaffeine-gcc6.patch to fix build with gcc6 (boo#985371)
* Wed Feb 24 2016 cgiboudeaux@gmx.com
- Add kaffeine-cmake34.patch. Include files containing the
  functions used by the build system.
* Wed Jan  6 2016 wbauer@tmo.at
- Symlink solid actions into place known to Plasma 5 (boo#960480)
* Sat Jun 27 2015 wbauer@tmo.at
- Add support_for_sundtek_tv_tuners.patch: add support for Sundtek
  (local and networkbased) TV devices (boo#827097)
* Sat Nov 15 2014 wbauer@tmo.at
- fix ksuseinstall to install libxine2-codecs, libxine1 is not used any more since 12.2
    (boo#858018)
* Wed Aug 21 2013 tittiatcoke@gmail.com
- fix ksuseinstall does not respect "don't ask again" (bnc# 671578)
  fix delivered by amolagodbole@gmail.com
* Thu Apr 19 2012 dmueller@suse.com
- provide/obsolete kaffeine-lang
* Tue Apr 17 2012 dmueller@suse.com
- fix build for older distros
* Mon Apr  2 2012 dimstar@opensuse.org
- Add kaffeine-gcc47.patch: Fix build with gcc 4.7.
* Tue Feb 28 2012 jslaby@suse.de
- fix crash on resume
* Thu Oct 27 2011 fisiu@opensuse.org
- Desktop menu entry moved to Video Player and TV.
* Fri Oct  7 2011 ctrippe@opensuse.org
- Remove patch fix_plasma_startup_error.diff as this causes kaffeine
  not beeing displayed as an action for audio-cds (bnc#722284)
* Wed Apr 27 2011 asterios.dramis@gmail.com
- Spec file updates:
  * Fix locales removal if suse_version is not set.
* Tue Apr 19 2011 asterios.dramis@gmail.com
- Update to 1.2.2:
  * fix crash after removing channels
- Spec file updates:
  * Added more descriptions for the patches based on openSUSE Patches
    Guidelines.
  * Fixed locales removal for openSUSE < 11.4.
  * Minor other updates.
- Fixed, rebased and applied fix_plasma_startup_error.diff patch.
* Thu Apr  7 2011 msvec@novell.com
- Update to 1.2.1:
  * add search function to epg
  * implement ATSC support for epg
  * fix gnome screen saver inhibition
  * other fixes and improvements
* Tue Feb 15 2011 ctrippe@gmx.net
- Add support for more mimetypes (bnc#671581)
* Tue Feb  8 2011 ctrippe@gmx.net
- Require libqt4-sql-sqlite (bnc#669793)
* Mon Jan 31 2011 asterios.dramis@gmail.com
- Spec file updates:
  * Changes based on rpmdevtools templates and spec-cleaner run.
  * Updates in Buildrequires: and %%install sections.
* Mon Dec 13 2010 coolo@novell.com
- add build fix for old qt versions
* Mon Dec 13 2010 coolo@novell.com
- fix file list for factory
* Mon Sep 27 2010 initialZero@gmail.com
- update to 1.1:
  * adapt to new shared-mime-info (so that .m2t is assigned to
    kaffeine again)
  * workaround issue that video isn't shown without changing tabs
    when using QT 4.7
  * recording schedule: fix sorting, improve column and dialog
    sizes, show a warning about active and pending recordings
    when closing kaffeine
  * program guide: remove the "Refresh" button (not necessary
    anymore)
  * channel editor: allow sorting by drag and drop
* Wed Jul  7 2010 initialZero@gmail.com
- update to 1.0:
  * new dependency: libXss
  * scheduled programs are shown in the program guide
  * the begin and end margins for recordings are configurable
  * CICAM is supported
  * all audio pids are recorded during timeshift
  * subtitle support (also autoloading)
* Wed Jul  7 2010 binner@kde.org
- fix build in KDE:UpdatedApps for <11.3
* Sat Jun 26 2010 cmorve69@yahoo.es
- Add InitialPreference to set it as the default video player
* Fri Jun 25 2010 beineri@opensuse.org
- fix build for <11.3
* Wed Apr 14 2010 llunak@novell.com
- support for on-demand codecs install using ksuseinstall
* Sun Mar 21 2010 jslaby@suse.de
- add libqt4-sql-sqlite to Requires
* Thu Mar 11 2010 initialZero@gmail.com
- update to 1.0-pre3:
  * new dependencies: Qt SQLite plugin, xine-lib, libX11
    (Phonon is no longer needed)
  * added configurable daily or weekly repetition of recording schedule entries
  * added support for dynamic audio / subtitles streams
  * reworked playlist support
  * added DBUS interface and partial MPRIS support
  * added dvd menu button and deinterlace option
* Sun Oct  4 2009 beineri@opensuse.org
- updated translations from SVN
* Mon Aug 10 2009 beineri@opensuse.org
- update to 1.0-pre2:
  * added screen saver inhibition (using DBUS; org.freedesktop.ScreenSaver)
  * added basic playlist features: .m3u, .pls, .xspf (+ old
    kaffeine format), drag and drop, repeat mode and shuffle
  * added OSD: various notifications, now and next epg
  * added DVB-S2 support using S2 API (old API still supported for non-S2 usage)
  * improved epg: save and restore events, possibility to schedule programs
* Sat Jul 25 2009 beineri@opensuse.org
- add trunk diff update (revision 1002342)
* Wed Jun  3 2009 beineri@opensuse.org
- copy application icon from oxygen trunk to fix start menu icon
  on every other/older KDE (bnc#509210)
* Tue Apr 28 2009 beineri@opensuse.org
- fix build
* Mon Apr 27 2009 tittiatcoke@gmail.com
- update to 1.0-pre1; This is the pre-release of the KDE4 version
  and is not really intended yet for end-users
* Wed Apr  8 2009 llunak@suse.cz
- fix build due to uint16_t
* Mon Jul  7 2008 dmueller@suse.de
- update to 0.8.7:
  * kaffeine: add MOD/STM mimetypes
  * kaffeine: fullscreen fix, patch by Einars Lielmanis <einars@gmail.com>
  * DVB: updated libdvb, added CAM menu.
  * DVB: added multiservices CAM support.
  * DVB: added ATSC scanning, patch by "Devin Heitmueller" <devin.heitmueller@gmail.com>
  * DVB: added 7MHz autoscan.
  * DVB: reworked CAM support.
* Wed Apr 30 2008 coolo@suse.de
- fix build
* Mon Feb  4 2008 schwab@suse.de
- Fix use of temporary object.
* Sun Jan 27 2008 stbinner@suse.de
- update to 0.8.6:
  * xine-part: added fastforward/slowmotion dcop calls, escape
    special chars, improved seeking, added screen resolution
    settings, added nextAudioChannel and nextSubtitleChannel to
    player menu dcop calls, fix audio/sub selection
  * several DVB fixes and improvements
  * CDDA: fixed encoding crash
  * kaffeine: requires xine-lib =>1.1.9
* Mon Aug 13 2007 coolo@suse.de
- don't duplicate the docs between -lang and base pack
* Fri Aug 10 2007 olh@suse.de
- remove private __u64 declaration, asm/types.h was fixed for -ansi
* Mon Aug  6 2007 dmueller@suse.de
- fix build
* Sun Jul 29 2007 stbinner@suse.de
- update to 0.8.5: several DVB related fixes and enhancements like
  * DVB: save/load epg data
  * DVB: add a "recall" button, that zap to previous played channel
  * DVB: make channel visible and selected after editing.
  * DVB: added a search field in channels list
* Wed Jun  6 2007 stbinner@suse.de
- replace playback hint URL also in to be translated text
* Mon Jun  4 2007 stbinner@suse.de
- fix build on older distributions
* Fri Jun  1 2007 coolo@suse.de
- move kde_post_install
* Mon May 14 2007 coolo@suse.de
- seperate translations into special package
* Sun Apr 29 2007 stbinner@suse.de
- fix build on 10.0
* Thu Apr 26 2007 dmueller@suse.de
- update dvb data
* Sat Apr 14 2007 stbinner@suse.de
- update to version 0.8.4:
  * Playlist: menu option to not auto switch to player window
  * DVB: added osd browsing dcop calls
  * xine-part: dragndrop subtitles files
  * fixed: removed readonly parts support
  * fixed: improve screensaver disabling method again
    (old behaviour for non-kde environments)
  * DVB: added a "source" column in channels list.
  * Playlist: fix opening playlists
  * DVB: rotors support (usals and mem_pos)
  * DVB: fixed multi devices usage.
  * DVB: fixed devices probing
  * DVB: added tuning timeout options
  * DVB: fixed OSD epg bug with diseqc settings
  * DVB: use klocale for datetime format
  * Playlist: fix google fetcher
  * xine-part: support for xcb. Requires libxcb 1.0 and xine-lib
    1.1.5. Fixes several issues.
  * gstreamer-part: port to gst 0.10
  * fixed: allow small window size in minimal mode
  * added: allow toggling (show / hide) panels by clicking tabs
  * xine-part: reduced audio/sub combos sizes
  * xine-part: add volume+/- to embedded context menu.
  * Playlist: don't cut bottom font in rollingtitle.
  * xine-part: better "Track infos" box layout.
  * xine-part: don't restore video settings if not previously saved
* Mon Dec  4 2006 stbinner@suse.de
- update to version 0.8.3:
  * DVB: selectAll button in scandialog
  * DVB: save channels list sort order
  * DVB: added "Current channel" button in epg window
  * xine-part: shortcuts for delay/advance subtitles (ctrl+alt+right/left)
  * xine-part: fixed wmv seeking.
  * xine-part: save and restore video settings (hue,saturation,contrast,brightness)
  * DVB: OSD warning when timeshift hd<300MB
  * added: option to start in minimal mode + dcop call.
  * added: "Open Dir" starts playing dvd from dir if dir points to a dvd image.
  * added: playing dvd iso files.
  * DVB: auto rename channels when adding to list
  * Disc: fixed crash trying to play while encoding
  * Disc: Ask user for cddb close matches
  * fixed: session issue.
  * fixed: better screensaver disabling method (no interfering key presses anymore).
  * DVB: fixed scanning services sharing same pmt.
  * DVB: added H/V (C band mutipoint) lnb settings.
  * DVB: improved device detection.
  * DVB: added : "int dvbSNR( int device )" dcop call.
  * fixed: crash when quit from systray.
* Mon Nov 27 2006 stbinner@suse.de
- fix one faulty German translation
* Sat Nov 25 2006 coolo@suse.de
- fix autoconf setup for translations (#223736)
* Mon Nov 13 2006 wstephenson@suse.de
- fix DVD playback warning dialog logic
* Mon Nov 13 2006 wstephenson@suse.de
- fix DVD playback warning URL
* Thu Nov  9 2006 stbinner@suse.de
- fix array subscript out of range (#212476)
* Sat Sep  9 2006 stbinner@suse.de
- update to version 0.8.2:
  * fixed: removed statusBar.
  * Disc: bigendian fix.
  * DVB: added current programm OSD progress bar
  * DVB: speed up OSD
  * DVB: fixed timer edit bug
  * DVB: added dvbNewTimer dcop func.
  * DVB: allow overlapping timers to start.
  * fixed: make sure to load xine_part instead of old kaffeine_part.
  * xine_part: removed empty audio/subtitles channels.
  * Kaffeine_part(s): added an entry in context menu to toggle
    minimal mode.
  * Playlist: added a "Clear Current Playlist" menu entry.
  * Playlist: autodownload cover now optional.
  * fixed: update google fetcher.
  * fixed: allow toggling from/to player/playlist even in fullscreen.
  * DVB: show SNR value for scanned channels, so a dvb-t user can
    choose the best one.
  * DVB: selectable channels icons (rigth click on a channel name
    in the list)
  * DVB: added "Scheduled" button in EPG window.
  * DVB: add dvb-t 8mhz autoscan mode for devices that support it.
  * fixed: switch to player window if mime does not contain "audio"
  * xine_part: block messages when filename contains "#"
  * DVB: cicam support, by Christoph Pfister * Systray: reversed
    mouse wheel behaviour.
  * Playlist: added a KURLComboBox to file browser.
  * DVB: fixed fast zap lock.
  * fixed: reduced minimum window size.
  * Playlist: autoselect subtitle when unique.
* Thu Aug 24 2006 stbinner@suse.de
- fix ability to switch back to kaffeine player engine (#159367)
* Thu Aug 17 2006 stbinner@suse.de
- fix x-mplayer2.desktop file conflict with kdelibs3
* Fri Jul 21 2006 schwab@suse.de
- Quote '&' in subtitle names in playlist [KDE#131180].
* Sun Jun  4 2006 coolo@suse.de
- allow Novell translations
* Mon May 15 2006 stbinner@suse.de
- update to version 0.8.1
  * fixed: configure check for cdparanoia.
  * Disc: force playing dvd/vcd with engine's default drive if
    kded_mediamanager fails to identify it.
  * kaffeine-part: plug dvd nav actions
  * DVB: write to fifo from a thread to circumvent deadlocks when
    xine stops (or fails) reading.
  * kaffeine-part: set skip forward/backward to 20s (to avoid
    "skating" when seeking in divx)
  * DVB: avoid negative freq value.
  * fixed: system:/media urls
  * fixed: include qapplication.h instead of qapp.h
  * fixed: use memcpy instead of mempcpy(gnu only) in ogg encoder.
  * fixed: ogg encoder makefile.
* Mon Apr 10 2006 jpr@suse.de
- Improve gstreamer 0.10 by getting visualization to work
* Sun Apr  9 2006 jpr@suse.de
- Move gstreamer part to 0.10
* Fri Mar 24 2006 dmueller@suse.de
- fix buffer overflow (#156952, CVE-2006-0051)
* Sat Mar 18 2006 coolo@suse.de
- fixed another case of system:/ problem (playing mp3s from CD
  would "download" the file first)
* Thu Feb 16 2006 coolo@suse.de
- backported SVN fix for system:/ URLs (#150527)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jan 12 2006 stbinner@suse.de
- Update URL in "DVDs cannot be played" messagebox to working one
- Better check if xine-lib packaged by SUSE is installed
* Sat Oct 22 2005 schwab@suse.de
- More finegraned locking.
* Fri Sep 16 2005 schwab@suse.de
- Fix missing mutex [#106044].
* Wed Sep  7 2005 schwab@suse.de
- Fix undefined operation.
* Tue Sep  6 2005 adrian@suse.de
- update to version 0.7.1
  * new translations
  * crash fix with empty DVB lists in EPG handler
* Mon Sep  5 2005 adrian@suse.de
- enable kaffeine kpart again, but do not associate any mimetypes
  (#115242)
* Tue Aug 30 2005 adrian@suse.de
- disable kaffeine kpart (#11406)
- disable some possible illegal links
- do not create system tray icon by default
* Sun Aug  7 2005 adrian@suse.de
- update to version 0.7
  * improved DVB support
  * optional Gstreamer support via kaffeine-gstreamer package
  * media:/ slave support
- remove xine-mad dependency
* Fri Aug  5 2005 coolo@suse.de
- some proofreading for our patches
* Wed Mar 30 2005 adrian@suse.de
- add czech translation from Klara
* Thu Mar 24 2005 adrian@suse.de
- update to version 0.6
  * DVB support merged from kaxtv
* Fri Mar 11 2005 adrian@suse.de
- remove too late XInitThread() call in kpart, which can cause a
  crash (#72072)
* Wed Mar  2 2005 adrian@suse.de
- add DVD warning dialog again
* Thu Feb 17 2005 adrian@suse.de
- menu entry moved to xdg dir
* Mon Jan  3 2005 coolo@suse.de
- fix installation of german man page
* Mon Jan  3 2005 adrian@suse.de
- update to version 0.5 final
* Wed Dec 22 2004 ro@suse.de
- only package english manpage for now
* Wed Nov 10 2004 adrian@suse.de
- update to version 0.5rc2
* Wed Oct  6 2004 adrian@suse.de
- update to version 0.5rc1
* Wed Sep 29 2004 adrian@suse.de
- fix broken desktop file syntax
* Wed Sep 29 2004 adrian@suse.de
- fix handling from streams
* Sun Sep 26 2004 adrian@suse.de
- adjust mimetypes to KDE 3.3 mimetypes
- remove realplayer support, the Helix plugin is not supported atm.
* Thu Aug 19 2004 adrian@suse.de
- use the logo codec file in theora format on SuSE 9.2 and later
* Wed Jun  2 2004 adrian@suse.de
- update to version 0.4.3b
* Mon May  3 2004 adrian@suse.de
- update to version 0.4.3
  * obsoletes XInitThread patch
* Fri Apr 16 2004 adrian@suse.de
- apply crash fix from Helio
* Tue Apr 13 2004 adrian@suse.de
- update to version 0.4.2
* Mon Apr  5 2004 adrian@suse.de
- update czech translations
* Tue Mar 16 2004 adrian@suse.de
- replace logo video. DivX4 won't work with our xine.
* Sat Feb 21 2004 adrian@suse.de
- remove Music from Categories
* Mon Jan 19 2004 adrian@suse.de
- update to version 0.4.1
* Sun Nov 16 2003 adrian@suse.de
- update to final 0.4 version
* Fri Nov  7 2003 adrian@suse.de
- fix build
- update to pre-0.4 snapshot
* Wed Oct  1 2003 adrian@suse.de
- use --nofork in desktop file or temporary files are get
  removed to early
* Sun Sep 21 2003 adrian@suse.de
- implement the message box different. It can get translated now
  and it solves also a crash in some cases. (#30224)
* Fri Sep 19 2003 adrian@suse.de
- from #31052
  * fix possible crash on quit
  * ask explizit for the "none" audio driver, if "auto" fails.
* Fri Sep 19 2003 adrian@suse.de
- add czech translation
* Thu Sep 18 2003 varkoly@suse.de
- add hungarian translation
* Sat Sep  6 2003 adrian@suse.de
- higher priority
- fix position change on pause
* Fri Sep  5 2003 adrian@suse.de
- justify Categories
* Sun Aug 24 2003 adrian@suse.de
- fix configure script to detect libXtest -> no DPMS anymore during
  playing
* Sat Aug 23 2003 adrian@suse.de
- drop some delete calls, which are reported as invalid by valgrind
  seems that fixes the crashes
* Mon Jul 28 2003 adrian@suse.de
- use new macro name for %%suse_update_desktop_file
* Mon Jul 28 2003 adrian@suse.de
- add Categories
* Wed Jul 16 2003 adrian@suse.de
- initial package of version 0.3.2
